@@ -187,7 +187,6 @@ enum : StringId
     STR_CANT_RAISE_WATER_LEVEL_HERE = 1167,
     STR_STRING = 1170,
     STR_RIDE_ENTRANCE_CLOSED = 1171,
-    STR_RIDE_ENTRANCE_NAME = 1172,
     STR_BANNER_SIGN_IN_THE_WAY = 1174,
     STR_CANT_BUILD_THIS_ON_SLOPED_FOOTPATH = 1175,
     STR_CANT_BUILD_FOOTPATH_HERE = 1176,
@@ -581,7 +580,7 @@ enum : StringId
     STR_CANT_BUY_CONSTRUCTION_RIGHTS_HERE = 1728,
     STR_LAND_NOT_OWNED_BY_PARK = 1729,
     STR_BANNER_TEXT_CLOSED = 1730,
-    STR_BANNER_TEXT_FORMAT = 1731,
+    STR_BANNER_TEXT_FORMAT = 7022,
     // STR_1737    :{COMMA16}
     STR_CANT_CHANGE_NUMBER_OF_LAPS = 1738,
     STR_RACE_WON_BY_GUEST = 1739,
@@ -602,7 +601,6 @@ enum : StringId
     STR_ONLY_ONE_CABLE_LIFT_HILL_PER_RIDE = 1774,
     // STR_OPTIONS_RIDE_MUSIC_OFF = 1775,
     // STR_OPTIONS_RIDE_MUSIC_ON = 1776,
-    STR_SCROLLING_SIGN_TEXT = 1778,
     // STR_STAFF_OPTION_COSTUME_PANDA = 1779,
     // STR_STAFF_OPTION_COSTUME_TIGER = 1780,
     // STR_STAFF_OPTION_COSTUME_ELEPHANT = 1781,
